@@ -15,9 +15,12 @@ goodfit <- function(x, type = c("poisson", "binomial", "nbinomial"),
         count <- as.vector(x[,2])
     }
 
-    ## eliminate zero frequencies
-    count <- count[!(freq < 1)]
-    freq <- freq[!(freq < 1)]
+    ## fill-in possibly missing cells
+    nfreq <- rep(0, max(count) + 1)
+    nfreq[count + 1] <- freq
+    freq <- nfreq
+    count <- 0:max(count)
+
     n <- length(count)
     df <- n - 1
 
@@ -61,6 +64,15 @@ goodfit <- function(x, type = c("poisson", "binomial", "nbinomial"),
         warning("size was not given, taken as maximum count")
       }
 
+      if(size > max(count)) {
+        nfreq <- rep(0, max(count) + 1)
+        nfreq[count + 1] <- freq
+        freq <- nfreq
+        count <- 0:max(count)
+        n <- length(count)
+        df <- n - 1      
+      }
+
       if(!is.null(par$prob)) {
         if(!is.list(par)) stop("`par' must be a named list and specify `prob'")
 	par <- par$prob
@@ -186,7 +198,7 @@ summary.goodfit <- function(object, ...)
     count <- object$count
     expctd <- fitted(object)
 
-    G2 <- sum(obsrvd * log(obsrvd/expctd)) * 2
+    G2 <- sum(ifelse(obsrvd == 0, 0, obsrvd * log(obsrvd/expctd))) * 2
 
     n <- length(obsrvd)
     switch(object$type,
